#!/usr/bin/env python3
"""
Model Configuration for CLI Discovery Stats.

Strongly-typed configuration class for CLI discovery stats.
"""


class ModelConfig:
    """Pydantic model configuration for CLI discovery stats."""
