"""Model metadata imports for security models."""

# Import existing evaluation models
from .model_cache_sizes import ModelCacheSizes
from .model_compliance_status import ModelComplianceStatus
from .model_enforcement_action import ModelEnforcementAction
from .model_evaluation_context import ModelEvaluationContext

# Import from separate file to break circular imports
from .model_evaluation_models import (
    ModelAuthorizationEvaluation,
    ModelComplianceEvaluation,
    ModelSignatureEvaluation,
)
from .model_performance_optimizations import ModelPerformanceOptimizations
from .model_performance_settings import ModelPerformanceSettings
from .model_policy_evaluation_details import ModelPolicyEvaluationDetails

# Import all extracted classes
from .model_signature_requirements import ModelSignatureRequirements
from .model_time_breakdown import ModelTimeBreakdown
from .model_trusted_nodes_info import ModelTrustedNodesInfo
from .model_verification_details import ModelVerificationDetails
from .model_verification_metrics import ModelVerificationMetrics
from .model_verification_result import ModelVerificationResult

# Import aliases for current standards with existing code
model_evaluation_context = ModelEvaluationContext
model_policy_evaluation_details = ModelPolicyEvaluationDetails

# Aliases for current standards
model_signature_evaluation = ModelSignatureEvaluation
model_compliance_evaluation = ModelComplianceEvaluation
model_authorization_evaluation = ModelAuthorizationEvaluation
model_signature_requirements = ModelSignatureRequirements
model_verification_result = ModelVerificationResult
model_compliance_status = ModelComplianceStatus
model_enforcement_action = ModelEnforcementAction
model_verification_details = ModelVerificationDetails
model_time_breakdown = ModelTimeBreakdown
model_performance_optimizations = ModelPerformanceOptimizations
model_verification_metrics = ModelVerificationMetrics
model_cache_sizes = ModelCacheSizes
model_trusted_nodes_info = ModelTrustedNodesInfo
model_performance_settings = ModelPerformanceSettings
