"""Tool input data model for protocol tool."""

from .model_tool_input_data_class import ModelToolInputData
from .model_tool_input_data_config import ModelConfig

__all__ = [
    "ModelToolInputData",
    "ModelConfig",
]
