"""External integrations for OmniNode.

Provides integration surfaces for external systems like Claude Code.
"""

from __future__ import annotations

from . import claude_code

__all__ = ["claude_code"]
