"""Input/Output models for Container Adapter tool.

This module provides convenience imports for all Container Adapter models
for current standards while following ONEX one-model-per-file standard.
"""

from omnibase_core.models.discovery.model_consul_event_bridge_input import (
    ModelConsulEventBridgeInput,
)
from omnibase_core.models.discovery.model_consul_event_bridge_output import (
    ModelConsulEventBridgeOutput,
)

# Import all individual models for current standards
from omnibase_core.models.discovery.model_container_adapter_input import (
    ModelContainerAdapterInput,
)
from omnibase_core.models.discovery.model_container_adapter_output import (
    ModelContainerAdapterOutput,
)
from omnibase_core.models.discovery.model_event_registry_coordinator_input import (
    ModelEventRegistryCoordinatorInput,
)
from omnibase_core.models.discovery.model_event_registry_coordinator_output import (
    ModelEventRegistryCoordinatorOutput,
)

# Re-export for current standards
__all__ = [
    "ModelConsulEventBridgeInput",
    "ModelConsulEventBridgeOutput",
    "ModelContainerAdapterInput",
    "ModelContainerAdapterOutput",
    "ModelEventRegistryCoordinatorInput",
    "ModelEventRegistryCoordinatorOutput",
]
