"""
Storage Health Status Model Config.

Pydantic model configuration for ONEX compliance.
"""


class ModelConfig:
    """Pydantic model configuration for ONEX compliance."""

    validate_assignment = True
