"""Logging models for ONEX structured logging infrastructure."""

from omnibase_core.models.logging.model_log_node_identifier import (
    ModelLogNodeIdentifier,
)

__all__ = ["ModelLogNodeIdentifier"]
